pub struct EventRef { /* private fields */ }Implementations
Sourceimpl EventRef
impl EventRef
Sourcepub unsafe fn from_raw(raw: *mut switch_event_t) -> Self
pub unsafe fn from_raw(raw: *mut switch_event_t) -> Self
Wraps a FreeSWITCH event pointer for the duration of a callback.
Safety
raw must point to a live FreeSWITCH event and remain valid while this wrapper is used.
pub fn as_ptr(self) -> *mut switch_event_t
pub fn header(self, name: impl AsRef<str>) -> Option<String>